OBS WebSocket RemoteControl
===========================

What's this?
------------
**obs-ws-rc** is a Python 3.5+ library that allows you to establish client
connections to the `obs-websocket <https://github.com/Palakis/obs-websocket/>`_
plugin for OBS Studio.

It uses an **asyncio**-based approach which it inherited from the underlying
WebSocket library - `websockets <https://github.com/aaugustin/websockets/>`_

Installation
------------
The library is `available via PyPi <https://pypi.python.org/pypi/obs-ws-rc>`_:

``pip install obs-ws-rc``

Source Code
-----------
GitHub repository: `github.com/KirillMysnik/obs-ws-rc/
<https://github.com/KirillMysnik/obs-ws-rc/>`_

Documentation
-------------
The docs are `hosted at Read the Docs <http://obs-ws-rc.readthedocs.io>`_

Examples
--------
Sample code is located in the `example folder
<https://github.com/KirillMysnik/obs-ws-rc/tree/master/examples>`_

License
-------
Available via `MIT License
<https://github.com/KirillMysnik/obs-ws-rc/blob/master/LICENSE>`_
